.. currentmodule:: hydromt_wflow.workflows

Workflows
=========

Several workflows were created for the wflow plugin. They are:

.. autosummary::
   :toctree: ../generated
   :nosignatures:

   glaciers.glaciermaps
   glaciers.glacierattrs
   river.river
   river.river_width
   soilgrids.soilgrids
   soilgrids.soilgrids_sediment
   waterbodies.waterbodymaps
   waterbodies.reservoirattrs

